@@ -165,6 +165,7 @@ void XMLParser::Pimpl::loadDocImpl(tinyxml2::XMLDocument* doc, bool add_includes
         std::string ros_pkg_path;
 #ifdef USING_ROS
         ros_pkg_path = ros::package::getPath(ros_pkg_relative_path);
+        file_path = filesystem::path(ros_pkg_path) / file_path;
 #elif defined USING_ROS2
         ros_pkg_path =
             ament_index_cpp::get_package_share_directory(ros_pkg_relative_path);
@@ -564,23 +565,24 @@ TreeNode::Ptr XMLParser::Pimpl::createNodeFromXML(const XMLElement* element,
         continue;
       }
       StringView param_value = remap_it->second;
-      auto param_res = TreeNode::getRemappedKey(port_name, param_value);
-      if (param_res)
+
+      if (auto param_res = TreeNode::getRemappedKey(port_name, param_value))
       {
+        // port_key will contain the key to find the entry in the blackboard
         const auto port_key = static_cast<std::string>(param_res.value());
 
-        auto prev_info = blackboard->portInfo(port_key);
-        if (!prev_info)
+        // if the entry already exists, check that the type is the same
+        if (auto prev_info = blackboard->portInfo(port_key))
         {
-          // not found, insert for the first time.
-          blackboard->setPortInfo(port_key, port_info);
-        }
-        else
-        {
-          // found. check consistency
-          if (prev_info->type() &&
-              port_info.type() &&   // null type means that everything is valid
-              *prev_info->type() != *port_info.type())
+          bool const port_type_mismatch = (prev_info->isStronglyTyped() &&
+                                           port_info.isStronglyTyped() &&
+                                           *prev_info->type() != *port_info.type());
+
+          // special case related to convertFromString
+          bool const string_input = ( prev_info->type() &&
+              *prev_info->type() == typeid(std::string));
+
+          if (port_type_mismatch && !string_input)
           {
             blackboard->debugMessage();
 
@@ -590,6 +592,11 @@ TreeNode::Ptr XMLParser::Pimpl::createNodeFromXML(const XMLElement* element,
                                demangle(port_info.type()), "] was used somewhere else.");
           }
         }
+        else
+        {
+          // not found, insert for the first time.
+          blackboard->createEntry(port_key, port_info);
+        }
       }
     }
 
@@ -707,8 +714,6 @@ void BT::XMLParser::Pimpl::recursivelyCreateTree(const std::string& tree_ID,
         output_tree.blackboard_stack.emplace_back(new_bb);
         std::set<StringView> mapped_keys;
 
-        bool do_autoremap = false;
-
         for (const XMLAttribute* attr = element->FirstAttribute(); attr != nullptr;
              attr = attr->Next())
         {
@@ -721,7 +726,8 @@ void BT::XMLParser::Pimpl::recursivelyCreateTree(const std::string& tree_ID,
           }
           if (StrEqual(attr_name, "__autoremap"))
           {
-            do_autoremap = convertFromString<bool>(attr_value);
+            bool do_autoremap = convertFromString<bool>(attr_value);
+            new_bb->enableAutoRemapping(do_autoremap);
             continue;
           }
 
@@ -740,21 +746,6 @@ void BT::XMLParser::Pimpl::recursivelyCreateTree(const std::string& tree_ID,
           }
         }
 
-        if (do_autoremap)
-        {
-          std::vector<std::string> remapped_ports;
-          auto new_root_element = tree_roots[node->name()]->FirstChildElement();
-
-          getPortsRecursively(new_root_element, remapped_ports);
-          for (const auto& port : remapped_ports)
-          {
-            if (mapped_keys.count(port) == 0)
-            {
-              new_bb->addSubtreeRemapping(port, port);
-            }
-          }
-        }
-
         recursivelyCreateTree(node->name(), output_tree, new_bb, node);
       }
     }
